import { RouterView } from 'vue-router';

export default {
    name: 'Ticket',
    path: '/ticket',
    meta: {
        title: 'tickets',
        icon: 'vn:ticket',
        moduleName: 'Ticket',
    },
    component: RouterView,
    redirect: { name: 'TicketMain' },
    menus: {
        main: ['TicketList', 'TicketAdvance', 'TicketWeekly', 'TicketFuture'],
        card: [
            'TicketBasicData',
            'TicketBoxing',
            'TicketSms',
            'TicketSale',
            'TicketLog',
            'TicketPurchaseRequest',
            'TicketVolume',
            'TicketNotes',
        ],
    },
    children: [
        {
            name: 'TicketMain',
            path: '',
            component: () => import('src/pages/Ticket/TicketMain.vue'),
            redirect: { name: 'TicketList' },
            children: [
                {
                    name: 'TicketList',
                    path: 'list',
                    meta: {
                        title: 'list',
                        icon: 'view_list',
                    },
                    component: () => import('src/pages/Ticket/TicketList.vue'),
                },
                {
                    name: 'TicketCreate',
                    path: 'create',
                    meta: {
                        title: 'createTicket',
                        icon: 'vn:ticketAdd',
                        roles: ['developer'],
                    },
                    component: () => import('src/pages/Ticket/TicketCreate.vue'),
                },
                {
                    name: 'TicketWeekly',
                    path: 'weekly',
                    meta: {
                        title: 'weeklyTickets',
                        icon: 'access_time',
                    },
                    component: () => import('src/pages/Ticket/TicketWeekly.vue'),
                },
                {
                    name: 'TicketFuture',
                    path: 'future',
                    meta: {
                        title: 'futureTickets',
                        icon: 'keyboard_double_arrow_right',
                    },
                    component: () => import('src/pages/Ticket/TicketFuture.vue'),
                },
                {
                    name: 'TicketAdvance',
                    path: 'advance',
                    meta: {
                        title: 'ticketAdvance',
                        icon: 'keyboard_double_arrow_left',
                    },
                    component: () => import('src/pages/Ticket/TicketAdvance.vue'),
                },
            ],
        },
        {
            name: 'TicketCard',
            path: ':id',
            component: () => import('src/pages/Ticket/Card/TicketCard.vue'),
            redirect: { name: 'TicketSummary' },
            children: [
                {
                    name: 'TicketSummary',
                    path: 'summary',
                    meta: {
                        title: 'summary',
                        icon: 'launch',
                    },
                    component: () => import('src/pages/Ticket/Card/TicketSummary.vue'),
                },
                {
                    name: 'TicketBasicData',
                    path: 'basic-data',
                    meta: {
                        title: 'basicData',
                        icon: 'vn:settings',
                    },
                    component: () =>
                        import('src/pages/Ticket/Card/BasicData/TicketBasicDataView.vue'),
                },
                {
                    name: 'TicketSale',
                    path: 'sale',
                    meta: {
                        title: 'sale',
                        icon: 'vn:lines',
                    },
                    component: () => import('src/pages/Ticket/Card/TicketSale.vue'),
                },
                {
                    path: 'request',
                    name: 'TicketPurchaseRequest',
                    meta: {
                        title: 'purchaseRequest',
                        icon: 'vn:buyrequest',
                    },
                    component: () =>
                        import('src/pages/Ticket/Card/TicketPurchaseRequest.vue'),
                },
                {
                    path: 'log',
                    name: 'TicketLog',
                    meta: {
                        title: 'log',
                        icon: 'history',
                    },
                    component: () => import('src/pages/Ticket/Card/TicketLog.vue'),
                },
                {
                    path: 'boxing',
                    name: 'TicketBoxing',
                    meta: {
                        title: 'boxing',
                        icon: 'vn:package',
                    },
                    component: () => import('src/pages/Ticket/Card/TicketBoxing.vue'),
                },
                {
                    path: 'sms',
                    name: 'TicketSms',
                    meta: {
                        title: 'sms',
                        icon: 'sms',
                    },
                    component: () => import('src/pages/Ticket/Card/TicketSms.vue'),
                },
                {
                    path: 'volume',
                    name: 'TicketVolume',
                    meta: {
                        title: 'volume',
                        icon: 'vn:volume',
                    },
                    component: () => import('src/pages/Ticket/Card/TicketVolume.vue'),
                },
                {
                    path: 'observation',
                    name: 'TicketNotes',
                    meta: {
                        title: 'notes',
                        icon: 'vn:notes',
                    },
                    component: () => import('src/pages/Ticket/Card/TicketNotes.vue'),
                },
            ],
        },
    ],
};
